==> glademm_0.6.4.orig.tar.gz: glademm-0.6.4/src/writers/dial.cc <==
// $Id: dial.cc,v 1.17 2001/10/11 14:07:24 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1998  Christof Petig
 *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "widget.hh"

class Gtk_Dial : public Gtk_Widget
{	const Widget get_adjustment(const Widget &w) const;
public:
	typedef Gtk_Widget Parent;
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gtk_Dial();
	virtual void Configure(const Widget &w, CxxFile &f,const std::string &instance) const;
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return false; }
	virtual void ConstructionArgs(Widget const &w, CxxFile &f) const
	{  f.FunctionArg(); }
	virtual bool CantMemberConstruct(const Widget &) const
	{  return true; }
	virtual void CreatePointer(const Widget &, CxxFile &) const;
	virtual void DestroyPointer(const Widget &w,CxxFile &f) const;
	virtual void GCInclude(const Widget &w, CxxFile &f) const;
};

static Gtk_Dial Gtk_Dial;

#define COPY_TAG(name) adjustment.push_back(Tag(name,w.getString(name)))
const Widget Gtk_Dial::get_adjustment(const Widget &w) const
{  static Tag adjustment("widget");
   std::string name(Configuration.InstanceName(w.Name())+"_adj");
   if (adjustment.getString("name")==name)
   {  return Widget(adjustment);
   }
   adjustment=Tag("widget");
   adjustment.push_back(Tag("class","GtkAdjustment"));
   adjustment.push_back(Tag("name",name));
   COPY_TAG("value");
   COPY_TAG("lower");
   COPY_TAG("upper");
   COPY_TAG("step");
   COPY_TAG("page");
   COPY_TAG("page_size");
   adjustment.push_back(Tag(CXX_IS_MANAGED,"true"));
   return Widget(adjustment);
}

const std::string Gtk_Dial::TypeName(const Widget &w) const
{  return GtkPrefix()+"Dial";
}

const std::string Gtk_Dial::IncludeName(const Widget &w) const
{  return "gnome--/dial.h";
}

void Gtk_Dial::GCInclude(const Widget &w, CxxFile &f) const
{  Parent::GCInclude(w,f);
   Widget w2(get_adjustment(w));
   LookupWriter(w2).GCInclude(w2,f);
}

Gtk_Dial::Gtk_Dial()
{  Writer["GtkDial"]=this;
}

void Gtk_Dial::Configure(const Widget &w, CxxFile &f,const std::string &instance) const
{  Parent::Configure(w,f,instance);
   Widget w2(get_adjustment(w));
   f.Statement() << instance << "set_adjustment(" << Reference(w2) << ')';
   std::string update_policy(w.getString("update_policy","GTK_UPDATE_CONTINUOUS"));
   f.Statement() << instance << "set_update_policy(" << update_policy << ')';
}

void Gtk_Dial::CreatePointer(const Widget &w,CxxFile &f) const
{  Widget w2(get_adjustment(w));
   LookupWriter(w2).CreatePointer(w2,f); 
   Parent::CreatePointer(w,f);
}

void Gtk_Dial::DestroyPointer(const Widget &w,CxxFile &f) const
{  Parent::DestroyPointer(w,f);
   Widget w2(get_adjustment(w));
   LookupWriter(w2).DestroyPointer(w2,f);
}

==> glademm_2.6.0.orig.tar.gz: glademm-2.6.0/src/writers/dial.cc <==
// $Id: dial.cc,v 1.21 2002/11/04 11:31:03 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1998  Christof Petig
 *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "widget.hh"

class Gtk_Dial : public Gtk_Widget
{	const Widget get_adjustment(const Widget &w) const;
public:
	typedef Gtk_Widget Parent;
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gtk_Dial();
	virtual void Configure(const Widget &w, CxxFile &f,const std::string &instance) const;
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return false; }
	virtual void ConstructionArgs(Widget const &w, CxxFile &f) const
	{  f.FunctionArg(); }
	virtual bool CantMemberConstruct(const Widget &) const
	{  return true; }
	virtual void CreatePointer(const Widget &, CxxFile &) const;
	virtual void DestroyPointer(const Widget &w,CxxFile &f) const;
	virtual void GCInclude(const Widget &w, CxxFile &f) const;
};

static Gtk_Dial Gtk_Dial;

#define COPY_TAG(name) w2.setProperty((name),w.getProperty(name))
const Widget Gtk_Dial::get_adjustment(const Widget &w) const
{  static Tag adjustment("widget");
   std::string name(Configuration.InstanceName(w.Name())+"_adj");
   if (Widget(adjustment).Name()==name)
   {  return Widget(adjustment);
   }
   adjustment=createWidgetTag("GtkAdjustment", name);
   Widget w2(adjustment);
   COPY_TAG("value");
   COPY_TAG("lower");
   COPY_TAG("upper");
   COPY_TAG("step");
   COPY_TAG("page");
   COPY_TAG("page_size");
   w2.setProperty(CXX_IS_MANAGED);
   return w2;
}

const std::string Gtk_Dial::TypeName(const Widget &w) const
{  return GtkPrefix()+"Dial";
}

const std::string Gtk_Dial::IncludeName(const Widget &w) const
{  return Configuration.GnomeUImmIncludePath()+"dial.h";
}

void Gtk_Dial::GCInclude(const Widget &w, CxxFile &f) const
{  Parent::GCInclude(w,f);
   Widget w2(get_adjustment(w));
   LookupWriter(w2).GCInclude(w2,f);
}

Gtk_Dial::Gtk_Dial()
{  Writer["GtkDial"]=this;
}

void Gtk_Dial::Configure(const Widget &w, CxxFile &f,const std::string &instance) const
{  Parent::Configure(w,f,instance);
   Widget w2(get_adjustment(w));
   f.Statement() << instance << "set_adjustment(" << Reference(w2) << ')';
   WriteEnumPropertyNS(w,f,instance, "update_policy");
}

void Gtk_Dial::CreatePointer(const Widget &w,CxxFile &f) const
{  Widget w2(get_adjustment(w));
   LookupWriter(w2).CreatePointer(w2,f); 
   Parent::CreatePointer(w,f);
}

void Gtk_Dial::DestroyPointer(const Widget &w,CxxFile &f) const
{  Parent::DestroyPointer(w,f);
   Widget w2(get_adjustment(w));
   LookupWriter(w2).DestroyPointer(w2,f);
}
